@@ -29,8 +29,7 @@ def create_app(console):
 
   @app.route('/upload', methods=['PUT'])
   def upload():
-    #file = NamedTemporaryFile(dir='/upload')
-    file = NamedTemporaryFile(dir='/tmp')
+    file = NamedTemporaryFile(dir='upload')
     try:
       data = request.get_data()
       print(f'data: {data}\n')
@@ -44,10 +43,10 @@ def create_app(console):
   return app
 
 def start_server(password, username, upstreams=False, upstreamh='0.0.0.0', upstreamp=55553, host="0.0.0.0", port=65432, *args, **kwargs):
-  client = MsfRpcClient(password, username=username, ssl=upstreams, server=upstreamh, port=upstreamp)
-  c_id = client.call(MsfRpcMethod.ConsoleCreate)['id']
+  client  = MsfRpcClient(password, username=username, ssl=upstreams, server=upstreamh, port=upstreamp)
+  c_id    = client.call(MsfRpcMethod.ConsoleCreate)['id']
   console = client.consoles.console(c_id)
-  app = create_app(console, **kwargs)
+  app     = create_app(console, **kwargs)
   app.run(debug=True, host=host, port=port, *args)
 
 # https://www.easydevguide.com/posts/curl_upload_flask
